from

# XMLRésuméLibrary: User Guide

firstname | Element Reference | gpa

## Name

from — The beginning point in a period of time

## Synopsis

### Content Model

    (date|present)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `from` element specifies the instant at which a given period of time begins. It is always followed by a `to` element in a `period`.

### Parents

`from` may be contained in these elements: `period`

## See Also

`to`.

## Examples

    <period>
      <from>
        <date>
          <dayOfMonth>26</dayOfMonth>
          <month>December</month>
          <year>1936</year>
        </date>
      </from>
      <to>
        <date>
          <dayOfMonth>14</dayOfMonth>
          <month>January</month>
          <year>2015</year>
        </date>
      </to>
    </period>

firstname | Element Reference | gpa